@@ -113,19 +113,38 @@ my %DefaultRules = (
 our @GlobalVersionDelta = (
     [
         '0.001' => <<'_EOC_',
-create table _general (
-    version varchar(10)
-);
-insert into _general (version) values ('0.001');
-create table _accounts (
-    id serial primary key,
-    name text unique not null
-);
+create or replace function _upgrade() returns integer as $$
+begin
+    create table _general (
+        version varchar(10)
+    );
+    insert into _general (version) values ('0.001');
+    create table _accounts (
+        id serial primary key,
+        name text unique not null
+    );
+    return 0;
+end;
+$$ language plpgsql;
 _EOC_
     ],
     [
         '0.002' => '',
-    ]
+    ],
+    [
+        '0.003' => '',
+    ],
+	[
+		'0.004' => <<"_EOC_",
+create or replace function _upgrade() returns integer as \$\$
+begin
+    alter table _global._general add column captcha_key char(16) not null
+    default '${\(random_secret())}';
+    return 0;
+end;
+\$\$ language plpgsql;
+_EOC_
+	],
 );
 
 our @LocalVersionDelta = (
@@ -207,6 +226,7 @@ end;
 $$ language plpgsql;
 _EOC_
     ],
+    [ '0.004' => '' ],
 );
 
 sub upgrade_all {
@@ -220,6 +240,9 @@ sub upgrade_all {
     my $base = $self->get_upgrading_base;
     if ($base < 0) {
         warn "Global metamodel is up to date.\n";
+    } else {
+        #### Upgrading global metamodel...
+        $self->upgrade_global_metamodel($base);
     }
     my @accounts = $self->get_all_accounts;
     #warn "@accounts";
@@ -264,17 +287,23 @@ sub upgrade_global_metamodel {
         $self->add_empty_user("_global");
         $self->set_user("_global");
     }
+    #### Upgrading global metamodel...
     $self->_upgrade_metamodel($base, \@GlobalVersionDelta);
 }
 
 sub upgrade_local_metamodel {
     my ($self, $base) = @_;
+
     if (!defined $base) { die "No upgrading base specified" }
     if ($base == 0) {
         if (!$self->has_user('_global')) {
+            my $user = $self->{user};
             $self->upgrade_global_metamodel(0);
+            $self->set_user($user);
         }
     }
+    #my @caller = caller;
+    #### upgrade_local_metamodel caller: @caller
     $self->_upgrade_metamodel($base, \@LocalVersionDelta);
 }
 
@@ -292,13 +321,20 @@ sub _upgrade_metamodel {
     }
     my $res;
     my $max = @$delta_table - 1;
+    #my @caller = caller;
+    #### caller: @caller
+    #### Upgrading meta model...
     for my $i ($base..$max) {
         my $entry = $delta_table->[$i];
         my ($new_ver, $sql) = @$entry;
-        if (!$sql) { next; }
         warn "Upgrading account $user from $cur_ver to $new_ver...\n";
+        if (!$sql) {
+            $res = $self->do("update _general set version='$new_ver'");
+            $cur_ver = $new_ver;
+            next;
+        }
         #$sql .= "; update _general set version='$new_ver'";
-        $res = $self->do("$sql");
+        $res = $self->do("$sql;");
         $res = $self->do("select _upgrade();");
         $res = $self->do("update _general set version='$new_ver'");
         #for my $stmt (split /;\n/, $sql) {
@@ -310,7 +346,7 @@ sub _upgrade_metamodel {
         #}
         $cur_ver = $new_ver;
     }
-    return $res >= 0;
+    return !defined $res || $res >= 0;
 }
 
 sub ping {
@@ -406,5 +442,39 @@ _EOC_
     $self->set_user($cur_user);
 }
 
+# generating random 16-bytes captcha secret key
+sub random_secret
+{
+	my @set=('0'..'9','a'..'z','A'..'Z');
+	my $key=join("",map {$set[int(rand(@set))]} (1..16));
+	return $key;
+}
+
+# check if the given string is a valid captcha secret
+# this sub should be called as a class method!
+sub is_valid_captcha_secret
+{
+	defined($_[1]) && length($_[1])==16 && $_[1]!~/[^0-9a-zA-Z]/;
+}
+
+# update the backend captcha secret
+sub update_captcha_secret
+{
+	my $self=shift||die;
+	my $secret=shift;
+
+	return undef unless $self->is_valid_captcha_secret($secret);
+
+	# quote string and escape any special characters to prevent SQL injection
+	$secret=$self->quote($secret);
+
+	# update captcha secret in the backend
+    my $cur_user = $self->{user};
+    $self->set_user('_global');
+    my $rv=$self->do("update _global._general set captcha_key=$secret");
+    $self->set_user($cur_user) if defined($cur_user);
+	return defined($rv)?1:undef;
+}
+
 1;
 
