@@ -7,7 +7,6 @@ use warnings;
 use CGI::Simple::Cookie;
 use OpenResty::Util;
 use Params::Util qw( _STRING );
-use Encode qw( decode is_utf8 );
 
 #*login = \&login_by_sql;
 *login = \&login_by_perl;
@@ -25,15 +24,6 @@ sub GET_login_user_password {
     $self->login($openresty, $user, { password => $password });
 }
 
-sub trim_sol {
-    my $s = $_[0];
-    unless (is_utf8($s)) {
-        $s = decode('UTF-8', $s);
-    }
-    $s =~ s/\W+//g;
-    $s;
-}
-
 sub login_by_sql {
     my ($self, $openresty, $user, $params) = @_;
     _STRING($user) or die "Bad user name: ", $OpenResty::Dumper->($user), "\n";
@@ -65,29 +55,11 @@ sub login_by_sql {
 
     if (defined $captcha) {
         my ($id, $user_sol) = split /:/, $captcha, 2;
-        ### Captcha ID: $id
-        my $true_sol = $OpenResty::Cache->get($id);
-        ### True sol: $true_sol
-        $OpenResty::Cache->remove($id);
-        if (!defined $true_sol) {
-            die "Capture ID is bad or expired.\n";
-        }
-        if ($true_sol eq '1') {
-            die "Captcha image never used.\n";
-        }
-        # XXX for testing purpose...
-        ### Account:  $account;
-        my $server = $ENV{OPENRESTY_TEST_SERVER} || $OpenResty::Config{'test_suite.server'};
-        if ($OpenResty::Config{'frontend.debug'} && $server =~ /^\Q$account\E\:/ && $role eq 'Poster') {
-            if ($true_sol =~ /[a-z]/) {
-                $true_sol = 'hello world ';
-            } else {
-                $true_sol = '你好世界';
-            }
-        }
-        if (trim_sol($user_sol) ne trim_sol($true_sol)) {
-            die "Solution to the captcha is incorrect.\n";
-        }
+
+		my ($rc,$err)=OpenResty::Handler::Captcha::validate_captcha($openresty,$id,$user_sol);
+		if (!$rc) {
+            die $err."\n";
+		}
     }
 
     $openresty->set_role($role);
@@ -166,29 +138,11 @@ sub login_by_perl {
         if ($res->[0][0] == 0) {
             die "Cannot login as $account.$role via captchas.\n";
         }
-        ### Captcha ID: $id
-        my $true_sol = $OpenResty::Cache->get($id);
-        ### True sol: $true_sol
-        $OpenResty::Cache->remove($id);
-        if (!defined $true_sol) {
-            die "Capture ID is bad or expired.\n";
-        }
-        if ($true_sol eq '1') {
-            die "Captcha image never used.\n";
-        }
-        # XXX for testing purpose...
-        ### Account:  $account;
-        my $server = $ENV{OPENRESTY_TEST_SERVER} || $OpenResty::Config{'test_suite.server'};
-        if ($OpenResty::Config{'frontend.debug'} && $server =~ /^\Q$account\E\:/ && $role eq 'Poster') {
-            if ($true_sol =~ /[a-z]/) {
-                $true_sol = 'hello world ';
-            } else {
-                $true_sol = '你好世界';
-            }
-        }
-        if (trim_sol($user_sol) ne trim_sol($true_sol)) {
-            die "Solution to the captcha is incorrect.\n";
-        }
+
+		my ($rc,$err)=OpenResty::Handler::Captcha::validate_captcha($openresty,$id,$user_sol);
+		if (!$rc) {
+            die $err."\n";
+		}
     } elsif (defined $password) {
         my $res = $openresty->select("select count(*) from _roles where name = " . Q($role) . " and login = 'password' and password = " . Q($password) . ";");
         ### with password: $res
@@ -214,7 +168,7 @@ sub login_by_perl {
 
     #my $captcha_from_cookie = $openresty->{_captcha_from_cookie};
     #if ($captcha_from_cookie) {
-    #$OpenResty::Cache->remove($captcha_from_cookie);
+	    #$OpenResty::Cache->remove($captcha_from_cookie);
     #}
 
     my $uuid = $OpenResty::UUID->create_str;
